@@ -6,23 +6,25 @@ use Module::Install::Base;
 
 use vars qw($VERSION @ISA);
 BEGIN {
-    $VERSION = '0.10';
+    $VERSION = '0.63';
     @ISA     = 'Module::Install::Base';
 }
 
 sub use_test_base {
-    my $self = shift; 
-    $self->build_requires('Test::Base' => '0.50');
+    my $self = shift;
     $self->include('Test::Base');
     $self->include('Test::Base::Filter');
     $self->include('Spiffy');
     $self->include('Test::More');
     $self->include('Test::Builder');
     $self->include('Test::Builder::Module');
+    $self->requires('Filter::Util::Call');
 }
 
 1;
 
+=encoding utf8
+
 =head1 NAME
 
 Module::Install::TestBase - Module::Install Support for Test::Base
@@ -58,7 +60,7 @@ Ingy döt Net <ingy@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006. Ingy döt Net. All rights reserved.
+Copyright (c) 2006, 2008, 2011, 2014. Ingy döt Net.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
